runtimehelper

package module
v0.5.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 24, 2026 License: MIT Imports: 3 Imported by: 2

README

runtimehelper

Go Reference

Helpers for Go's runtime package.

Documentation

Overview

Package runtimehelper contains runtime package helpers.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CallerCallerName

func CallerCallerName() string

CallerCallerName returns name of the function that called the function that called CallerCallerName. In case of any failure empty string is returned.

func CallerName

func CallerName() string

CallerName returns name of the function that called CallerName. In case of any failure empty string is returned.

func JustFunctionName added in v0.4.0

func JustFunctionName(nm string) string

JustFunctionName returns just function name of the full function name returned by Func.Name.

func JustPackageFunctionName added in v0.4.0

func JustPackageFunctionName(nm string) string

JustPackageFunctionName returns just function name preceded with package name of the full function name returned by Func.Name. Generic type parameters (e.g. "[int]") are stripped from the result.

func NthCallerName added in v0.2.0

func NthCallerName(n int) string

NthCallerName returns name of the n-th caller function of NthCallerName. In case of any failure empty string is returned. For n's meaning see runtime.Caller documentation.

Types

This section is empty.

Jump to