Documentation
¶
Overview ¶
Package runtimehelper contains runtime package helpers.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CallerCallerName ¶
func CallerCallerName() string
CallerCallerName returns name of the function that called the function that called CallerCallerName. In case of any failure empty string is returned.
func CallerName ¶
func CallerName() string
CallerName returns name of the function that called CallerName. In case of any failure empty string is returned.
func JustFunctionName ¶ added in v0.4.0
JustFunctionName returns just function name of the full function name returned by Func.Name.
func JustPackageFunctionName ¶ added in v0.4.0
JustPackageFunctionName returns just function name preceded with package name of the full function name returned by Func.Name. Generic type parameters (e.g. "[int]") are stripped from the result.
func NthCallerName ¶ added in v0.2.0
NthCallerName returns name of the n-th caller function of NthCallerName. In case of any failure empty string is returned. For n's meaning see runtime.Caller documentation.
Types ¶
This section is empty.