runtimehelper

package module
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 19, 2026 License: MIT Imports: 3 Imported by: 2

README

runtimehelper

Go Reference

Helpers for Go's runtime package.

Documentation

Overview

Package runtimehelper contains runtime package helpers.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CallerCallerName

func CallerCallerName() string

CallerCallerName returns name of the function that called the function that called CallerCallerName. In case of any failure empty string is returned.

func CallerName

func CallerName() string

CallerName returns name of the function that called CallerName. In case of any failure empty string is returned.

func JustName added in v0.3.0

func JustName(nm string) string

JustName returns just function name of the full function name returned by Func.Name.

func JustNameWithPackage added in v0.3.0

func JustNameWithPackage(nm string) string

JustNameWithPackage returns just function name preceeded with package name of the full function name returned by Func.Name.

func NthCallerName added in v0.2.0

func NthCallerName(n int) string

NthCallerName returns name of the n-th caller function of NthCallerName. In case of any failure empty string is returned. For n's meaning see runtime.Caller documentation.

Types

This section is empty.

Jump to