runtimehelper

package module
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 22, 2023 License: MIT Imports: 1 Imported by: 2

README

runtimehelper

Go Reference

Helpers for Go's runtime package.

Documentation

Overview

Package runtimehelper contains runtime package helpers.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CallerCallerName

func CallerCallerName() string

CallerCallerName returns name of the function that called the function that called CallerCallerName. In case of any failure empty string is returned.

func CallerName

func CallerName() string

CallerName returns name of the function that called CallerName. In case of any failure empty string is returned.

Types

This section is empty.

Jump to