Documentation
¶
Overview ¶
Package runtimehelper contains runtime package helpers.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CallerCallerName ¶
func CallerCallerName() string
CallerCallerName returns name of the function that called the function that called CallerCallerName. In case of any failure empty string is returned.
func CallerName ¶
func CallerName() string
CallerName returns name of the function that called CallerName. In case of any failure empty string is returned.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.